Commit: 8d1dc22becf22b96ff4095fe0243ec04a9bc61c5
Author: Mike Erwin
Date:   Mon Mar 30 00:51:00 2015 -0400
Branches: master
https://developer.blender.org/rB8d1dc22becf22b96ff4095fe0243ec04a9bc61c5

cleanup: typos in comments, style

no functional changes

===================================================================

M       source/blender/editors/space_view3d/drawobject.c

===================================================================

diff --git a/source/blender/editors/space_view3d/drawobject.c 
b/source/blender/editors/space_view3d/drawobject.c
index 808408b..1f30d25 100644
--- a/source/blender/editors/space_view3d/drawobject.c
+++ b/source/blender/editors/space_view3d/drawobject.c
@@ -598,10 +598,10 @@ void drawaxes(float size, char drawtype)
 }
 
 
-/* Function to draw an Image on a empty Object */
+/* Function to draw an Image on an empty Object */
 static void draw_empty_image(Object *ob, const short dflag, const unsigned 
char ob_wire_col[4])
 {
-       Image *ima = (Image *)ob->data;
+       Image *ima = ob->data;
        ImBuf *ibuf = BKE_image_acquire_ibuf(ima, ob->iuser, NULL);
 
        float scale, ofs_x, ofs_y, sca_x, sca_y;
@@ -641,7 +641,7 @@ static void draw_empty_image(Object *ob, const short dflag, 
const unsigned char
                sca_y = 1.0f;
        }
 
        /* Calculate the scale center based on objects origin */
        ofs_x = ob->ima_ofs[0] * ima_x;
        ofs_y = ob->ima_ofs[1] * ima_y;
 
@@ -944,7 +944,7 @@ void view3d_cached_text_draw_end(View3D *v3d, ARegion *ar, 
bool depth_write, flo
 
 /* ******************** primitive drawing ******************* */
 
-/* draws a cube on given the scaling of the cube, assuming that
+/* draws a cube given the scaling of the cube, assuming that
  * all required matrices have been set (used for drawing empties)
  */
 static void drawcube_size(float size)
@@ -1026,8 +1026,6 @@ static void drawshadbuflimits(Lamp *la, float mat[4][4])
        glPointSize(1.0);
 }
 
-
-
 static void spotvolume(float lvec[3], float vvec[3], const float inp)
 {
        /* camera is at 0,0,0 */
@@ -1036,8 +1034,8 @@ static void spotvolume(float lvec[3], float vvec[3], 
const float inp)
        normalize_v3(lvec);
        normalize_v3(vvec);             /* is this the correct vector ? */
 
-       cross_v3_v3v3(temp, vvec, lvec);      /* equation for a plane through 
vvec en lvec */
-       cross_v3_v3v3(plane, lvec, temp);     /* a plane perpendicular to this, 
parrallel with lvec */
+       cross_v3_v3v3(temp, vvec, lvec);      /* equation for a plane through 
vvec and lvec */
+       cross_v3_v3v3(plane, lvec, temp);     /* a plane perpendicular to this, 
parallel with lvec */
 
        /* vectors are exactly aligned, use the X axis, this is arbitrary */
        if (normalize_v3(plane) == 0.0f)
@@ -1162,7 +1160,7 @@ static void drawlamp(View3D *v3d, RegionView3D *rv3d, 
Base *base,
 
        unsigned char curcol[4];
        unsigned char col[4];
-       /* cone can't be drawn for duplicated lamps, because duplilist would be 
freed to */
+       /* cone can't be drawn for duplicated lamps, because duplilist would be 
freed */
        /* the moment of view3d_draw_transp() call */
        const bool is_view = (rv3d->persp == RV3D_CAMOB && v3d->camera == 
base->object);
        const bool drawcone = ((dt > OB_WIRE) &&
@@ -1311,7 +1309,7 @@ static void drawlamp(View3D *v3d, RegionView3D *rv3d, 
Base *base,
                x *= y;
 
                /* draw the circle/square at the end of the cone */
-               glTranslatef(0.0, 0.0,  x);
+               glTranslatef(0.0, 0.0, x);
                if (la->mode & LA_SQUARE) {
                        float tvec[3];
                        float z_abs = fabsf(z);
@@ -1500,10 +1498,10 @@ static void draw_limit_line(float sta, float end, const 
short dflag, unsigned in
 static void draw_focus_cross(float dist, float size)
 {
        glBegin(GL_LINES);
-       glVertex3f(-size, 0.f, -dist);
-       glVertex3f(size, 0.f, -dist);
-       glVertex3f(0.f, -size, -dist);
-       glVertex3f(0.f, size, -dist);
+       glVertex3f(-size, 0.0f, -dist);
+       glVertex3f(size, 0.0f, -dist);
+       glVertex3f(0.0f, -size, -dist);
+       glVertex3f(0.0f, size, -dist);
        glEnd();
 }
 
@@ -1556,8 +1554,7 @@ static void draw_viewport_object_reconstruction(Scene 
*scene, Base *base, View3D
        BKE_tracking_get_camera_object_matrix(scene, base->object, mat);
 
        /* we're compensating camera size for bundles size,
-        * to make it so bundles are always displayed with the same size
-        */
+        * to make it so bundles are always displayed with the same size */
        copy_v3_v3(camera_size, base->object->size);
        if ((tracking_object->flag & TRACKING_OBJECT_CAMERA) == 0)
                mul_v3_fl(camera_size, tracking_object->scale);
@@ -1991,9 +1988,9 @@ static void ensure_curve_cache(Scene *scene, Object 
*object)
         * here, we also need to check whether display list is
         * empty or not.
         *
-        * The trick below tries to optimie calls to displist
+        * The trick below tries to optimize calls to displist
         * creation for cases curve is empty. Meaning, if the curve
-        * is empty (without splies) bevel list would also be empty.
+        * is empty (without splines) bevel list would also be empty.
         * And the thing is, render thread always leaves bevel list
         * in a proper state. So if bevel list is here and display
         * list is not we need to make display list.
@@ -2271,8 +2268,7 @@ static void draw_dm_verts__mapFunc(void *userData, int 
index, const float co[3],
        BMVert *eve = BM_vert_at_index(data->bm, index);
 
        if (!BM_elem_flag_test(eve, BM_ELEM_HIDDEN) && BM_elem_flag_test(eve, 
BM_ELEM_SELECT) == data->sel) {
-               /* skin nodes: draw a red circle around the root
-                * node(s) */
+               /* skin nodes: draw a red circle around the root node(s) */
                if (data->cd_vskin_offset != -1) {
                        const MVertSkin *vs = BM_ELEM_CD_GET_VOID_P(eve, 
data->cd_vskin_offset);
                        if (vs->flag & MVERT_SKIN_ROOT) {
@@ -2355,7 +2351,7 @@ static DMDrawOption 
draw_dm_edges_sel__setDrawOptions(void *userData, int index)
                        else {
                                col = data->baseCol;
                        }
-                       /* no alpha, this is used so a transparent color can 
disable drawing unselected edges in editmode  */
+                       /* no alpha, this is used so a transparent color can 
disable drawing unselected edges in editmode */
                        if (col[3] == 0)
                                return DM_DRAW_OPTION_SKIP;
                        
@@ -3045,7 +3041,7 @@ static void draw_em_measure_stats(ARegion *ar, View3D 
*v3d, Object *ob, BMEditMe
                }
 
                BM_ITER_MESH (eed, &iter, em->bm, BM_EDGES_OF_MESH) {
-                       /* draw selected edges, or edges next to selected verts 
while draging */
+                       /* draw selected edges, or edges next to selected verts 
while dragging */
                        if (BM_elem_flag_test(eed, BM_ELEM_SELECT) ||
                            (do_moving && (BM_elem_flag_test(eed->v1, 
BM_ELEM_SELECT) ||
                                           BM_elem_flag_test(eed->v2, 
BM_ELEM_SELECT))))
@@ -3107,12 +3103,12 @@ static void draw_em_measure_stats(ARegion *ar, View3D 
*v3d, Object *ob, BMEditMe
                BM_ITER_MESH (eed, &iter, em->bm, BM_EDGES_OF_MESH) {
                        BMLoop *l_a, *l_b;
                        if (BM_edge_loop_pair(eed, &l_a, &l_b)) {
-                               /* draw selected edges, or edges next to 
selected verts while draging */
+                               /* draw selected edges, or edges next to 
selected verts while dragging */
                                if (BM_elem_flag_test(eed, BM_ELEM_SELECT) ||
                                    (do_moving && (BM_elem_flag_test(eed->v1, 
BM_ELEM_SELECT) ||
                                                   BM_elem_flag_test(eed->v2, 
BM_ELEM_SELECT) ||
-                                                  /* special case, this is 
useful to show when vertes connected to this edge via a
-                                                   * face are being 
transformed */
+                                                  /* special case, this is 
useful to show when verts connected to
+                                                   * this edge via a face are 
being transformed */
                                                   
BM_elem_flag_test(l_a->next->next->v, BM_ELEM_SELECT) ||
                                                   
BM_elem_flag_test(l_a->prev->v, BM_ELEM_SELECT)       ||
                                                   
BM_elem_flag_test(l_b->next->next->v, BM_ELEM_SELECT) ||
@@ -3418,7 +3414,7 @@ static void draw_em_fancy(Scene *scene, ARegion *ar, 
View3D *v3d,
        
        if (em->bm->selected.last) {
                BMEditSelection *ese = em->bm->selected.last;
-               /* face is handeled above */
+               /* face is handled above */
 #if 0
                if (ese->type == BM_FACE) {
                        efa_act = (BMFace *)ese->data;
@@ -3533,11 +3529,14 @@ static void draw_em_fancy(Scene *scene, ARegion *ar, 
View3D *v3d,
        }
        else if (efa_act) {
                /* even if draw faces is off it would be nice to draw the 
stipple face
-                * Make all other faces zero alpha except for the active
-                * */
-               /* col4 is only used by WITH_FREESTYLE, but keeping it here 
spares some #ifdef's... */
-               unsigned char col1[4], col2[4], col3[4], col4[4];
-               col1[3] = col2[3] = col4[3] = 0; /* don't draw */
+                * Make all other faces zero alpha except for the active */
+               unsigned char col1[4], col2[4], col3[4];
+#ifdef WITH_FREESTYLE
+               unsigned char col4[4];
+               col4[3] = 0; /* don't draw */
+#endif
+               col1[3] = col2[3] = 0; /* don't draw */
+
                UI_GetThemeColor4ubv(TH_EDITMESH_ACTIVE, col3);
 
                glEnable(GL_BLEND);
@@ -3551,7 +3550,6 @@ static void draw_em_fancy(Scene *scene, ARegion *ar, 
View3D *v3d,
 
                glDisable(GL_BLEND);
                glDepthMask(1);  /* restore write in zbuffer */
-
        }
 
        /* here starts all fancy draw-extra over */
@@ -3734,7 +3732,7 @@ static void draw_mesh_fancy(Scene *scene, ARegion *ar, 
View3D *v3d, RegionView3D
                glPointSize(1.0);
        }
        else if (dt == OB_WIRE || totface == 0) {
-               draw_wire = OBDRAW_WIRE_ON; /* draw wire only, no depth buffer 
stuff  */
+               draw_wire = OBDRAW_WIRE_ON; /* draw wire only, no depth buffer 
stuff */
        }
        else if (((is_obact && ob->mode & OB_MODE_TEXTURE_PAINT)) ||
                 check_object_draw_texture(scene, v3d, dt))
@@ -3776,8 +3774,10 @@ static void draw_mesh_fancy(Scene *scene, ARegion *ar, 
View3D *v3d, RegionView3D
                        else
                                dm->drawFacesGLSL(dm, GPU_enable_material);
 
-//                     if (BKE_bproperty_object_get(ob, "Text"))
-// XXX                         draw_mesh_text(ob, 1);
+#if 0 /* XXX */
+                       if (BKE_bproperty_object_get(ob, "Text"))
+                               draw_mesh_text(ob, 1);
+#endif
                        GPU_disable_material();
 
                        glFrontFace(GL_CCW);
@@ -3895,7 +3895,7 @@ static void draw_mesh_fancy(Scene *scene, ARegion *ar, 
View3D *v3d, RegionView3D
        }
 
        if ((draw_wire != OBDRAW_WIRE_OFF) &&  /* draw extra wire */
-           /* when overriding with render only, don't bother  */
+           /* when overriding with render only, don't bother */
            (((v3d->flag2 & V3D_RENDER_OVERRIDE) && v3d->drawtype >= OB_SOLID) 
== 0))
        {
                /* When using wireframe object draw in particle edit mode
@@ -3949,7 +3949,7 @@ static void draw_mesh_fancy(Scene *scene, ARegion *ar, 
View3D *v3d, RegionView3D
        dm->release(dm);
 }
 
-/* returns 1 if nothing was drawn, for detecting to draw an object center */
+/* returns true if nothing was drawn, for detecting to draw an object center */
 static bool draw_mesh_object(Scene *scene, ARegion *ar, View3D *v3d

@@ Diff output truncated at 10240 characters. @@
@@ -641,7 +641,7 @@ static void draw_empty_image(Object *ob, const short dflag, 
        }
 
-       /* Calculate the scale center based on objects origin */
+       /* Calculate the scale center based on object's origin */
        ofs_x = ob->ima_ofs[0] * ima_x;
        ofs_y = ob->ima_ofs[1] * ima_y;

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
http://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to